@@ -718,7 +718,7 @@ static void nvkms_kthread_q_callback(void *arg)
      * pending timers and than waiting for workqueue callbacks.
      */
     if (timer->kernel_timer_created) {
-        timer_delete_sync(&timer->kernel_timer);
+        del_timer_sync(&timer->kernel_timer);
     }
 
     /*
@@ -1740,7 +1740,7 @@ restart:
              * completion, and we wait for queue completion with
              * nv_kthread_q_stop below.
              */
-            if (timer_delete_sync(&timer->kernel_timer) == 1) {
+            if (del_timer_sync(&timer->kernel_timer) == 1) {
                 /*  We've deactivated timer so we need to clean after it */
                 list_del(&timer->timers_list);
 
@@ -1778,7 +1778,6 @@ restart:
 module_init(nvkms_init);
 module_exit(nvkms_exit);
 
-MODULE_DESCRIPTION("NVIDIA GPU modeset kernel module");
 #if defined(MODULE_LICENSE)
 
 
